# kyss

Kyss is a YAML-inspired configuration language that keeps it simple.

This repository includes a parser, an API to define schemas for more advanced usage, and a commandline tool that converts kyss-format files to Python syntax or JSON.

[![PyPI - Version](https://img.shields.io/pypi/v/kyss.svg)](https://pypi.org/project/kyss)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kyss.svg)](https://pypi.org/project/kyss)

*You don't have to be universal to be my choice*  
*You don't have to support cycles to rule my world*  
*Ain't no particular JSON I'm compatible with*  
*I just want your config files and your*

:kiss: *Kyss* :kiss:

(With apologies to Prince)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install kyss
```

## License

`kyss` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
